@@ -14,12 +14,8 @@ PRAXIS_NS = 'http://www.praxis.com.mx/'
 class Orden(BaseModel):
     id: int
     categoria: types.CategoriaOrdenPago
-
-    op_ord_clave: types.ClaveOrdenanteOrdenPago = types.ClaveOrdenanteOrdenPago.AMU
-
     op_fecha_oper: int
     op_folio: str
-    op_ins_clave: digits(3, 5)
     op_monto: str
     op_tp_clave: types.TipoPagoOrdenPago
     op_cve_rastreo: str
@@ -38,11 +34,13 @@ class Orden(BaseModel):
     op_tc_clave_ord: types.TipoCuentaOrdenPago = None
     op_cuenta_ord: str = None
     op_rfc_curp_ord: str = None
+    op_ins_clave_ord: digits(3, 5) = types.ClaveOrdenanteOrdenPago.AMU
 
     op_nom_ben: str = None
     op_tc_clave_ben: types.TipoCuentaOrdenPago = None
     op_cuenta_ben: str = None
     op_rfc_curp_ben: str = None
+    op_ins_clave_ben: digits(3, 5) = None
 
     op_nom_ben_2: str = None
     op_tc_clave_ben_2: types.TipoCuentaOrdenPago = None
@@ -115,7 +113,7 @@ class Orden(BaseModel):
 
         elements = self.dict(
             exclude_none=True,
-            exclude={'id', 'categoria', 'op_ord_clave'},
+            exclude={'id', 'categoria', 'op_ins_clave_ord'},
         )
 
         for element, value in elements.items():  # noqa: WPS110
@@ -143,6 +141,8 @@ class Orden(BaseModel):
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
                 orden_data[tag] = element.text
+            if tag == 'op_ins_clave':
+                orden_data['op_ins_clave_ben'] = element.text
 
         return cls(**orden_data)
 
@@ -261,11 +261,6 @@ class TerceroATerceroFSW(Orden):
     op_cuenta_ben: str = None
     op_rfc_curp_ben: str = None
 
-    op_nom_ben_2: str = None
-    op_tc_clave_ben_2: types.TipoCuentaOrdenPago = None
-    op_cuenta_ben_2: str = None
-    op_rfc_curp_ben_2: str = None
-
     op_concepto_pag_2: str
     op_iva: float = None
     op_ref_numerica: str
